<!--
 * @Author: BDFD
 * @Date: 2021-10-27 18:39:19
 * @LastEditTime: 2022-07-25 17:55:17
 * @LastEditors: BDFD
 * @Description: In User Settings Edit
 * @FilePath: \Section5.3-PyPi_Feature_Engineering\README.md
-->

# Package Name

Fast Analysis

Ultimate Goal: Make Feature Engineering Analysis easy and fast as it should be.

## Installation

`pip install bifeatureanalysis`

## How to use it?

Feature Engineering Analysis Common Usage Function List

## License

copyright @ 2022 BDFD

This repository is licensed under the MIT license. See LICENSE for details.

### References

https://github.com/bdfd/Section5.3-PyPi_Feature_Engineering
